==> haskell-hxt-9.3.1.16-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt
version: 9.3.1.16
id: hxt-9.3.1.16-5pQ3Livn3zj3r6Ptb0ciqB
key: hxt-9.3.1.16-5pQ3Livn3zj3r6Ptb0ciqB
license: MIT
copyright: Copyright (c) 2005-20161 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: A collection of tools for processing XML with Haskell.
description:
    The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
    but introduces a more general approach for processing XML with Haskell.
    The Haskell XML Toolbox uses a generic data model for representing XML documents,
    including the DTD subset and the document subset, in Haskell.
    It contains a validating XML parser, a HTML parser, namespace support,
    an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
    and funtions for serialization and deserialization of user defined data.
    The library makes extensive use of the arrow approach for processing XML.
    Since version 9 the toolbox is partitioned into various (sub-)packages.
    This package contains the core functionality,
    hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt,
    hxt-regex-xmlschema contain the extensions.
    hxt-unicode contains encoding and decoding functions,
    hxt-charproperties char properties for unicode and XML.
    .
    Changes from 9.3.1.15: Bug in quoting PI instructions in showXmlTrees fixed
    .
    Changes from 9.3.1.14: For ghc-7.10 network-uri is automatically selected
    .
    Changes from 9.3.1.13: ghc-7.10 compatibility
    .
    Changes from 9.3.1.12: Bug when unpickling an empty attribute value removed
    .
    Changes from 9.3.1.11: Bug fix in haddock comments
    .
    Changes from 9.3.1.10: Bug in DTD validation, space and time leak in delta removed
    .
    Changes from 9.3.1.9: lower bound of mtl dependency lowered to 2.0.1
    .
    Changes from 9.3.1.8: Bug in hread removed
    .
    Changes from 9.3.1.7: Foldable and Traversable instances for NTree added
    Control.Except used instead of deprecated Control.Error
    .
    Changes from 9.3.1.6: canonicalize added in hread and hreadDoc
    .
    Changes from 9.3.1.4: conditionally (no default)
    dependency from networt changed to network-uri with flag "network-uri"
    .
    Changes from 9.3.1.3: warnings from ghc-7.8.1 removed
    .
    Changes from 9.3.1.2: https as protocol added
    .
    Changes from 9.3.1.1: new parser xreadDoc
    .
    Changes from 9.3.1.0: in readString all input decoding switched off
    .
    Changes from 9.3.0.1: lower bound for network set to be >= 2.4
    .
    Changes from 9.3.0: upper bound for network set to be < 2.4
    (URI signatures changed in 2.4)
    .
    Changes from 9.2.2: XMLSchema validation integrated
    .
    Changes from 9.2.1: user defined mime type handlers added
    .
    Changes from 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
indefinite: False
exposed-modules:
    Control.Arrow.ArrowExc Control.Arrow.ArrowIO Control.Arrow.ArrowIf
    Control.Arrow.ArrowList Control.Arrow.ArrowNF
    Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
    Control.Arrow.ArrowTree Control.Arrow.IOListArrow
    Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
    Control.Arrow.ListArrows Control.Arrow.NTreeEdit
    Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
    Data.Atom Data.Function.Selector Data.Tree.Class
    Data.Tree.NTree.Edit Data.Tree.NTree.TypeDefs
    Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
    Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
    Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
    Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
    Text.XML.HXT.Arrow.GeneralEntitySubstitution
    Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
    Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
    Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
    Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
    Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
    Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
    Text.XML.HXT.Arrow.XmlState
    Text.XML.HXT.Arrow.XmlState.ErrorHandling
    Text.XML.HXT.Arrow.XmlState.MimeTypeTable
    Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
    Text.XML.HXT.Arrow.XmlState.SystemConfig
    Text.XML.HXT.Arrow.XmlState.TraceHandling
    Text.XML.HXT.Arrow.XmlState.TypeDefs
    Text.XML.HXT.Arrow.XmlState.URIHandling Text.XML.HXT.Core
    Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
    Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
    Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
    Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
    Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
    Text.XML.HXT.DTDValidation.AttributeValueValidation
    Text.XML.HXT.DTDValidation.DTDValidation
    Text.XML.HXT.DTDValidation.DocTransformation
    Text.XML.HXT.DTDValidation.DocValidation
    Text.XML.HXT.DTDValidation.IdValidation
    Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
    Text.XML.HXT.DTDValidation.Validation
    Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
    Text.XML.HXT.Parser.HtmlParsec
    Text.XML.HXT.Parser.ProtocolHandlerUtil
    Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
    Text.XML.HXT.Parser.XmlDTDParser
    Text.XML.HXT.Parser.XmlDTDTokenParser
    Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
    Text.XML.HXT.Parser.XmlTokenParser Text.XML.HXT.Version
    Text.XML.HXT.XMLSchema.DataTypeLibW3CNames
abi: 42a5a42ca6a3bc716fd71a1a16ccf785
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-9.3.1.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-9.3.1.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-9.3.1.16
hs-libraries: HShxt-9.3.1.16-5pQ3Livn3zj3r6Ptb0ciqB
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH deepseq-1.4.3.0
    bytestring-0.10.8.2 binary-0.8.5.1
    hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
    hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5
    hxt-regex-xmlschema-9.2.0.3-WKEiNBuPmGJPoQftKO5hX
    network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v=128140e73626722dd834f67c7ef8810c
             hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5=46e93b79a769bd2c42b608d189acd933
             hxt-regex-xmlschema-9.2.0.3-WKEiNBuPmGJPoQftKO5hX=3eb9eba6a74d794d74968fd1a74ae9af
             network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS=2690938855a63b0d59221887564a11f0
haddock-interfaces: /usr/share/doc/haskell-hxt/html/hxt.haddock
haddock-html: /usr/share/doc/haskell-hxt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-9.3.1.16-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt
version: 9.3.1.16
id: hxt-9.3.1.16-GY9Xj7S1ft2ILS8g9VY0K6
key: hxt-9.3.1.16-GY9Xj7S1ft2ILS8g9VY0K6
license: MIT
copyright: Copyright (c) 2005-20161 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: A collection of tools for processing XML with Haskell.
description:
    The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
    but introduces a more general approach for processing XML with Haskell.
    The Haskell XML Toolbox uses a generic data model for representing XML documents,
    including the DTD subset and the document subset, in Haskell.
    It contains a validating XML parser, a HTML parser, namespace support,
    an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
    and funtions for serialization and deserialization of user defined data.
    The library makes extensive use of the arrow approach for processing XML.
    Since version 9 the toolbox is partitioned into various (sub-)packages.
    This package contains the core functionality,
    hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt,
    hxt-regex-xmlschema contain the extensions.
    hxt-unicode contains encoding and decoding functions,
    hxt-charproperties char properties for unicode and XML.
    .
    Changes from 9.3.1.15: Bug in quoting PI instructions in showXmlTrees fixed
    .
    Changes from 9.3.1.14: For ghc-7.10 network-uri is automatically selected
    .
    Changes from 9.3.1.13: ghc-7.10 compatibility
    .
    Changes from 9.3.1.12: Bug when unpickling an empty attribute value removed
    .
    Changes from 9.3.1.11: Bug fix in haddock comments
    .
    Changes from 9.3.1.10: Bug in DTD validation, space and time leak in delta removed
    .
    Changes from 9.3.1.9: lower bound of mtl dependency lowered to 2.0.1
    .
    Changes from 9.3.1.8: Bug in hread removed
    .
    Changes from 9.3.1.7: Foldable and Traversable instances for NTree added
    Control.Except used instead of deprecated Control.Error
    .
    Changes from 9.3.1.6: canonicalize added in hread and hreadDoc
    .
    Changes from 9.3.1.4: conditionally (no default)
    dependency from networt changed to network-uri with flag "network-uri"
    .
    Changes from 9.3.1.3: warnings from ghc-7.8.1 removed
    .
    Changes from 9.3.1.2: https as protocol added
    .
    Changes from 9.3.1.1: new parser xreadDoc
    .
    Changes from 9.3.1.0: in readString all input decoding switched off
    .
    Changes from 9.3.0.1: lower bound for network set to be >= 2.4
    .
    Changes from 9.3.0: upper bound for network set to be < 2.4
    (URI signatures changed in 2.4)
    .
    Changes from 9.2.2: XMLSchema validation integrated
    .
    Changes from 9.2.1: user defined mime type handlers added
    .
    Changes from 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
indefinite: False
exposed-modules:
    Control.Arrow.ArrowExc Control.Arrow.ArrowIO Control.Arrow.ArrowIf
    Control.Arrow.ArrowList Control.Arrow.ArrowNF
    Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
    Control.Arrow.ArrowTree Control.Arrow.IOListArrow
    Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
    Control.Arrow.ListArrows Control.Arrow.NTreeEdit
    Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
    Data.Atom Data.Function.Selector Data.Tree.Class
    Data.Tree.NTree.Edit Data.Tree.NTree.TypeDefs
    Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
    Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
    Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
    Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
    Text.XML.HXT.Arrow.GeneralEntitySubstitution
    Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
    Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
    Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
    Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
    Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
    Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
    Text.XML.HXT.Arrow.XmlState
    Text.XML.HXT.Arrow.XmlState.ErrorHandling
    Text.XML.HXT.Arrow.XmlState.MimeTypeTable
    Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
    Text.XML.HXT.Arrow.XmlState.SystemConfig
    Text.XML.HXT.Arrow.XmlState.TraceHandling
    Text.XML.HXT.Arrow.XmlState.TypeDefs
    Text.XML.HXT.Arrow.XmlState.URIHandling Text.XML.HXT.Core
    Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
    Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
    Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
    Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
    Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
    Text.XML.HXT.DTDValidation.AttributeValueValidation
    Text.XML.HXT.DTDValidation.DTDValidation
    Text.XML.HXT.DTDValidation.DocTransformation
    Text.XML.HXT.DTDValidation.DocValidation
    Text.XML.HXT.DTDValidation.IdValidation
    Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
    Text.XML.HXT.DTDValidation.Validation
    Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
    Text.XML.HXT.Parser.HtmlParsec
    Text.XML.HXT.Parser.ProtocolHandlerUtil
    Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
    Text.XML.HXT.Parser.XmlDTDParser
    Text.XML.HXT.Parser.XmlDTDTokenParser
    Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
    Text.XML.HXT.Parser.XmlTokenParser Text.XML.HXT.Version
    Text.XML.HXT.XMLSchema.DataTypeLibW3CNames
abi: 40a4cf4dcb273cd92fd4aacf154bc118
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-9.3.1.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-9.3.1.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-9.3.1.16
hs-libraries: HShxt-9.3.1.16-GY9Xj7S1ft2ILS8g9VY0K6
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc deepseq-1.4.3.0
    bytestring-0.10.8.2 binary-0.8.5.1
    hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
    hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5
    hxt-regex-xmlschema-9.2.0.3-HBeQMJB5xjo9wBO3m0UdGm
    network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v=128140e73626722dd834f67c7ef8810c
             hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5=46e93b79a769bd2c42b608d189acd933
             hxt-regex-xmlschema-9.2.0.3-HBeQMJB5xjo9wBO3m0UdGm=4e83e03bfc0b3f0adf0bcfad6bd44798
             network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ=17ff77631878cfceba90438df04f39d6
haddock-interfaces: /usr/share/doc/haskell-hxt/html/hxt.haddock
haddock-html: /usr/share/doc/haskell-hxt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
